summaryrefslogtreecommitdiff
path: root/src/device/usbd.c
diff options
context:
space:
mode:
authorNathan Conrad <[email protected]>2020-04-13 09:25:16 -0400
committerNathan Conrad <[email protected]>2020-04-13 09:51:46 -0400
commitf8e7487355c1d48517211a2316fbbc8566a1532d (patch)
treea5617b08460972c7ad6055c95548ff0b2f77a6ba /src/device/usbd.c
parent0eeaccaf46c28444cc0830895559652cf5638c60 (diff)
edpt_close: Updated based on feedback.
Diffstat (limited to 'src/device/usbd.c')
-rw-r--r--src/device/usbd.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/device/usbd.c b/src/device/usbd.c
index e46532567..71f5454ee 100644
--- a/src/device/usbd.c
+++ b/src/device/usbd.c
@@ -1044,6 +1044,8 @@ bool usbd_edpt_stalled(uint8_t rhport, uint8_t ep_addr)
/**
* Remove queued xfer complete messages from event queue,
* for a particular ep.
+ *
+ * Must be called with interrupts enabled.
*/
static void usbd_abort_transfers(uint8_t rhport, uint8_t ep_addr)
{
@@ -1077,13 +1079,13 @@ static void usbd_abort_transfers(uint8_t rhport, uint8_t ep_addr)
}
/**
* tud_edpt_close will disable an endpoint, and clear all pending transfers
* through the particular endpoint.
*
- * It must be called from the usb task (i.e. from the control request
- * handler while handling SET_ALTERNATE).
+ * It must be called from the usb task (e.g. from the control request
+ * handler while handling SET_ALTERNATE), with interrupts enabled.
*/
-void tud_edpt_close(uint8_t rhport, uint8_t ep_addr)
+void usbd_edpt_close(uint8_t rhport, uint8_t ep_addr)
{
TU_ASSERT(dcd_edpt_close, /**/);
@@ -1077,13 +1079,13 @@ static void usbd_abort_transfers(uint8_t rhport, uint8_t ep_addr)
}
/**
- * tud_edpt_close will disable an endpoint, and clear all pending transfers
+ * usbd_edpt_close will disable an endpoint, and clear all pending transfers
* through the particular endpoint.
*